@@ -4,14 +4,10 @@ use warnings;
 
 use Carp qw<croak>;
 
-use GDPR::IAB::TCFv2::BitUtils qw<is_set
+use GDPR::IAB::TCFv2::BitUtils qw<
   get_uint2
-  get_uint3
   get_uint6
   get_uint12
-  get_uint16
-  get_uint36
-  get_char6_pair
 >;
 
 use constant ASSUMED_MAX_VENDOR_ID => 0x7FFF;    # 32767 or (1 << 15) -1
